.. _advanced_topics:
.. index:: Advanced topics

Advanced topics
***************

This section demonstrates the use of :program:`icet` via a set of examples that
showcase different features and modes of usage.

The scripts and database that are required for this tutorial can be downloaded
as a single zip archive. To this end, run the following command from the
command line::

    curl -O https://icet.materialsmodeling.org/advanced_topics.zip
    unzip advanced_topics.zip

.. toctree::
   :maxdepth: 1
   :caption: Contents

   structure_enumeration
   mapping_structures
   wang_landau_simulations
   parallel_monte_carlo
   hybrid_ensembles
   sqs_generation
   customizing_cluster_spaces
   constituent_strain
   cluster_vectors
   data_container
